# Cytonic

A Python framework to define REST APIs and automatically generate server side bindings and clients.

__Features__

* Generate Python language bindings from YAML API definitions
* Use the same bindings for clients and to implement the server side

## Quickstart

Check out the [examples/todolist](examples/todolist) folder.

## Why the name "Cytonic"?

The name is inspired by the great Skyward book series by Brandon Sanderson, where "cytonics" are people
or other organisms that can enter the space of the delvers to teleport to any location in the galaxy.
